//
// prints a help message on the screen
//
#include "config.h"                        // for email to send bug reports
#include "plotdata.h"

void prn_info(char** argv)
{
  string pgname = basename(argv[0]);                 // chops long pathname

  if (pgname.rfind(".exe") != string::npos) {
    pgname.replace(pgname.find(".exe"),4,"");
  }

  cerr <<
    "\n \033[1m" << pgname << "\033[0m, when given a single"
    " argument \033[1mdatafile\033[0m (the name of your data\n"
    " file), will plot the data contained in that \033[1mdatafile\033[0m.\n\n"
    " The \033[1mdatafile\033[0m must have either two or three columns of numbers, separated by\n"
    " spaces or tabs.  The first column must contain the \033[1mx\033[0m values and the second\n"
    " column the associated \033[1my\033[0m values.  The optional third column (if it exists),\n"
    " must contain the associated uncertainties (\033[1msigmas\033[0m) of the \033[1my\033[0m values.\n"
    " (The program assumes that the \033[1mx\033[0m values are precisely known, so that all\n"
    " uncertainties are associated with the \033[1my\033[0m values.)\n\n"

    " If the uncertainties are independently estimated, say, for example, by\n"
    " calculating the standard error of the mean for a number of \033[1my\033[0m values for each\n"
    " \033[1mx\033[0m value, these uncertainties will appear on the graph as \"error bars\".\n"
    " In this case, the \"\033[1m--sigmas\033[0m\" (or \"\033[1m-s\033[0m\") option should be specified.  If the\n"
    " \"\033[1m--sigmas\033[0m\" option is not specified, the third column of the \033[1mdatafile\033[0m will be\n"
    " ignored, and no error bars will appear on the graph, just as if the third\n"
    " column were completely absent.\n\n"

    " The \033[1mdatafile\033[0m may contain comments or other blocks of text.  These lines of\n"
    " text, along with any blank lines, will be ignored by the program when\n"
    " producing the graph.  A typical \033[1mdatafile\033[0m might have lines such as these:\n\n"

    "         -----------------------------------------\n"
    "         data for a single gaussian lineshape from\n"
    "            the X-ray fluorescence experiment\n"
    "             CHAN#  COUNTS  SIGMA\n"
    "         -----------------------------------------\n"
    "               9     490    22.14\n"
    "              10     517    22.74\n"
    "              11     530    23.02\n\n"

    " Production of the graph requires that \033[1mPython\033[0m, \033[1mNumpy\033[0m, and \033[1mMatplotlib\033[0m be\n"
    " installed on your computer, and the program will display the particular\n"
    " versions of these packages that are used.  In testing this program we have\n"
    " used \033[1mPython\033[0m version 2.7, \033[1mNumpy\033[0m version 1.8.1, and \033[1mMatplotlib\033[0m version 1.2.0.\n\n"

    " The program will ask you to supply a title for your graph, along with labels\n"
    " for the \033[1mx\033[0m and \033[1my\033[0m axes.  A \"time/date\" string may be inserted for any label by\n"
    " by typing \" td\", i.e., by typing those two characters, preceded by a space.\n"
    " Also, newline characters (\033[1m\\n\033[0m) may be inserted in any title or label to format\n"
    " multiple line labels.  For example, a title might be specified as something\n"
    " like this:\n\n"

    "   A Gaussian line from the X-ray experiment,\\nwith data plotted at td.\n\n"

    " The python script, called \033[1mdatafile.py\033[0m, may be edited with your favorite\n"
    " editor if you want to change the title or axis labels, or add any text to the\n"
    " graph itself.  When the graph is first displayed by the program it may be\n"
    " exited (hit the \"X\" or \"Ctrl-C\"), after which the program will ask if you\n"
    " want to remove the temporary file (\033[1mdatafile.tmp\033[0m).  Be sure to say \"no\" if\n"
    " you want to edit the python script, since that file contains the data used\n"
    " by the script, and the script won't run without that file.\n\n"

    " To add text to the graph itself, see the comment lines in the Python script.\n"
    " Note that your graph may be saved as either a \033[1m.png\033[0m image or a \033[1m.pdf\033[0m file.\n\n"

    " Trouble or bug reports?  Send an email to Peter Scott <" << PACKAGE_BUGREPORT << ">.\n\n"

    " \t\t-------------------------------------\n";

  prn_usage(argv);
}
